@@ -21,6 +21,10 @@ from xworkflows import base
 
 State = base.State
 AbortTransition = base.AbortTransition
+ForbiddenTransition = base.ForbiddenTransition
+InvalidTransitionError = base.InvalidTransitionError
+WorkflowError = base.WorkflowError
+
 transition = base.transition
 
 
@@ -275,31 +279,52 @@ class TransactionalImplementationWrapper(base.ImplementationWrapper):
 
 
 class Workflow(base.Workflow):
-    """Extended workflow that handles object saving and logging to the database."""
+    """Extended workflow that handles object saving and logging to the database.
 
-    #: Save log to this django model
+    Attributes:
+        log_model (str): the name of the log model to use; if empty, logging to
+            database will be disabled.
+        log_model_class (obj): the class for the log model; resolved once django
+            is completely loaded.
+    """
+
+    #: Save log to this django model (name of the model)
     log_model = get_default_log_model()
 
-    #: Run all transitions withi a transaction.
+    #: Run all transitions within a transaction.
     implementation_class = TransactionalImplementationWrapper
 
-    def __init__(self, log_model=None, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
+        # Fetch 'log_model' if overridden.
+        log_model = kwargs.pop('log_model', self.log_model)
+
         super(Workflow, self).__init__(*args, **kwargs)
 
-        if log_model is None:
-            log_model = self.log_model
-
-        if log_model:
-            app_label, model_label = log_model.rsplit('.', 1)
-            log_model = models.get_model(app_label, model_label)
         self.log_model = log_model
+        self.log_model_class = None
+
+    def _get_log_model_class(self):
+        """Cache for fetching the actual log model object once django is loaded.
+
+        Otherwise, import conflict occur: WorkflowEnabled import <log_model>
+        which tries to import all models to retrieve the proper model class.
+        """
+        if self.log_model_class is not None:
+            return self.log_model_class
+
+        app_label, model_label = self.log_model.rsplit('.', 1)
+        self.log_model_class = models.get_model(app_label, model_label)
+        return self.log_model_class
 
     def db_log(self, transition, from_state, instance, user=None, *args, **kwargs):
         """Logs the transition into the database."""
         if self.log_model:
-            self.log_model.objects.create(modified_object=instance,
-                                         transition=transition.name,
-                                         user=user)
+            model_class = self._get_log_model_class()
+            model_class.objects.create(modified_object=instance,
+                                       transition=transition.name,
+                                       from_state=from_state.name,
+                                       to_state=transition.target.name,
+                                       user=user)
 
     def log_transition(self, transition, from_state, instance,
             save=True, log=True, *args, **kwargs):
