@@ -32,9 +32,17 @@ class MyAltWorkflow(dxmodels.Workflow):
     )
     initial_state = 'a'
 
+    log_model = ''
+
 
 class MyWorkflowEnabled(dxmodels.WorkflowEnabled, models.Model):
+    OTHER_CHOICES = (
+        ('aaa', u"AAA"),
+        ('bbb', u"BBB"),
+    )
+
     state = dxmodels.StateField(MyWorkflow)
+    other = models.CharField(max_length=4, choices=OTHER_CHOICES)
 
     def fail_if_fortytwo(self, res, *args, **kwargs):
         if res == 42:
