@@ -38,6 +38,10 @@ class ModelTestCase(unittest.TestCase):
         o = models.MyWorkflowEnabled()
         self.assertEqual(models.MyWorkflow.states['foo'], o.state)
 
+    def test_instantiation_from_empty(self):
+        o = models.MyWorkflowEnabled(state=None)
+        self.assertEqual(models.MyWorkflow.states['foo'], o.state)
+
     def test_class_attribute(self):
         self.assertEqual(models.MyWorkflow, models.MyWorkflowEnabled.state.__class__)
 
@@ -59,6 +63,11 @@ class ModelTestCase(unittest.TestCase):
         self.assertRaises(exceptions.ValidationError, set_invalid_state)
         self.assertEqual(models.MyWorkflow.states['foo'], o.state)
 
+    def test_display(self):
+        o = models.MyWorkflowEnabled(other='aaa')
+        self.assertEqual(u"Foo", o.get_state_display())
+        self.assertEqual(u"AAA", o.get_other_display())
+
     def test_queries(self):
         models.MyWorkflowEnabled.objects.all().delete()
 
@@ -94,7 +103,7 @@ class ModelTestCase(unittest.TestCase):
     def test_invalid_dump(self):
         data = '[{"pk": 1, "model": "djworkflows.myworkflowenabled", "fields": {"state": "blah"}}]'
 
-        self.assertRaises(serializers.base.DeserializationError, list,
+        self.assertRaises(exceptions.ValidationError, list,
             serializers.deserialize('json', data))
 
 
@@ -135,6 +144,25 @@ class TransitionTestCase(unittest.TestCase):
         self.assertEqual(self.obj, trlog.modified_object)
         self.assertEqual('foobar', trlog.transition)
         self.assertEqual(None, trlog.user)
+        self.assertEqual('foo', trlog.from_state)
+        self.assertEqual('bar', trlog.to_state)
+
+        self.assertIn('foo -> bar', unicode(trlog))
+
+    def test_no_logging(self):
+        """Tests disabled transition logs."""
+        xwlog_models.TransitionLog.objects.all().delete()
+
+        obj = models.WithTwoWorkflows()
+        obj.save()
+
+        # No log model on MyAltWorkflow
+        obj.tob()
+        self.assertFalse(xwlog_models.TransitionLog.objects.exists())
+
+        # Log model provided for MyWorkflow
+        obj.foobar()
+        self.assertTrue(xwlog_models.TransitionLog.objects.exists())
 
     def test_saving(self):
         self.obj.save()
